/**
 * Returns true if a variable is an object.
 */
var isObject = function (value) {
    return (typeof value === "object" &&
        value !== null &&
        !Array.isArray(value) &&
        !(value instanceof RegExp) &&
        !(value instanceof Date) &&
        !(value instanceof Set) &&
        !(value instanceof Map));
};
/**
 * Fills a given object (`userObj`) with default object (`defaultObj`) for the undefined or optional keys, and returns the new object.
 */
export var defaultFill = function (defaultObj, userObj) {
    var newObject = structuredClone(defaultObj);
    if (isObject(defaultObj) && isObject(userObj)) {
        for (var key in defaultObj) {
            if (key in userObj &&
                userObj[key] !== undefined) {
                var defaultVal = defaultObj[key];
                var userVal = userObj[key];
                if (typeof defaultVal !== typeof userVal) {
                    console.warn("Bad key-value pair encountered:", { key: userVal }, "\nUsing default value.");
                    continue;
                }
                if (isObject(defaultVal)) {
                    newObject[key] = defaultFill(defaultVal, userVal);
                    continue;
                }
                newObject[key] = userVal;
            }
        }
    }
    return newObject;
};
